sops

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 31, 2023 License: MIT Imports: 4 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Decrypt

func Decrypt(encrypted, privKeyPath string) (string, error)

Decrypt takes a string of encrypted data and returns the plaintext

func Encrypt

func Encrypt(plaintext, pubKeyPath string) (string, error)

Encrypt takes a string of plaintext data and returns the encrypted data

func GetSopsInstallCommand

func GetSopsInstallCommand() (string, error)

GetSopsInstallCommand returns the command to install sops based on the OS

Types

This section is empty.

Jump to